"""
    Este é o módulo "neter.py", e fornece uma função chamda print_lol()
    que imprime listas de podem ou não incluir listas aninhadas
"""

def print_lol(the_list, level=0):
    """
        Esta função requer um argumento possicional chamado "the_list", que é
        qualquer lista python (de possiveis listas aninhadas). Cada item de dados na
        lista fornecida é (recursivamente) impresso na tela em sua própria linha.
    """
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab_level in range(level):
                print("\t", end='')
            print(each_item)



